/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global define*/

/**
 * Options model module.
 *
 * @module models/options
 * @namespace models/options
 * @memberof models
 */

define({
    name: 'models/options',
    def: function modelsOptions() {
        'use strict';

        /**
         * Default stroke width.
         *
         * @private
         * @const {number}
         */
        var DEFAULT_STROKE_WIDTH = 1,

            /**
             * Default stroke color.
             *
             * @private
             * @const {string}
             */
            DEFAULT_STROKE_COLOR = '#fff',

            /**
             * Stroke width value.
             *
             * @private
             * @type {number}
             */
            strokeWidth = DEFAULT_STROKE_WIDTH,

            /**
             * Stroke color value.
             *
             * @private
             * @type {string}
             */
            strokeColor = DEFAULT_STROKE_COLOR;

        /**
         * Returns stroke width.
         *
         * @memberof models/options
         * @public
         * @returns {number}
         */
        function getStrokeWidth() {
            return strokeWidth;
        }

        /**
         * Sets stroke width.
         *
         * @memberof models/options
         * @public
         * @param {number} value
         */
        function setStrokeWidth(value) {
            strokeWidth = parseFloat(value);
        }

        /**
         * Returns stroke color.
         *
         * @memberof models/options
         * @public
         * @returns {string}
         */
        function getStrokeColor() {
            return strokeColor;
        }

        /**
         * Sets stroke color.
         *
         * @memberof models/options
         * @public
         * @param {string} value
         */
        function setStrokeColor(value) {
            strokeColor = value;
        }

        return {
            getStrokeWidth: getStrokeWidth,
            setStrokeWidth: setStrokeWidth,
            getStrokeColor: getStrokeColor,
            setStrokeColor: setStrokeColor
        };
    }

});
